@@ -1,6 +1,9 @@
 """Provide a model for the Z-Wave JS value."""
+import json
 from typing import TYPE_CHECKING, Any, Dict, Optional, TypedDict, Union
 
+from ..const import ConfigurationValueType, VALUE_UNKNOWN
+from ..exceptions import UnparseableValue
 from ..event import Event
 
 if TYPE_CHECKING:
@@ -33,17 +36,41 @@ class ValueDataType(TypedDict, total=False):
     propertyKey: Union[str, int]
     propertyKeyName: str
     value: Any
+    newValue: Any
+    prevValue: Any
     metadata: MetaDataType
     ccVersion: int
 
 
-def get_value_id(node: "Node", event_data: ValueDataType) -> str:
+def _get_value_id_from_dict(node: "Node", val: ValueDataType) -> str:
+    """Return ID of value from ValueDataType dict."""
+    return get_value_id(
+        node,
+        val["commandClass"],
+        val["property"],
+        val.get("endpoint"),
+        val.get("propertyKey"),
+        val.get("propertyKeyName"),
+    )
+
+
+def get_value_id(
+    node: "Node",
+    command_class: int,
+    property_: Union[str, int],
+    endpoint: Optional[int] = None,
+    property_key: Optional[Union[str, int]] = None,
+    property_key_name: Optional[str] = None,
+) -> str:
     """Return ID of value."""
-    command_class = event_data["commandClass"]
-    endpoint = event_data.get("endpoint") or "00"
-    property_ = event_data["property"]
-    property_key_name = event_data.get("propertyKeyName") or "00"
-    return f"{node.node_id}-{command_class}-{endpoint}-{property_}-{property_key_name}"
+    endpoint_ = "00" if endpoint is None else endpoint
+    if property_key is None:
+        property_key = "00"
+    property_key_name = property_key_name or "00"
+    return (
+        f"{node.node_id}-{command_class}-{endpoint_}-"
+        f"{property_}-{property_key}-{property_key_name}"
+    )
 
 
 class ValueMetadata:
@@ -73,6 +100,11 @@ class ValueMetadata:
         """Return label."""
         return self.data.get("label")
 
+    @property
+    def description(self) -> Optional[str]:
+        """Return description."""
+        return self.data.get("description")
+
     @property
     def min(self) -> Optional[int]:
         """Return min."""
@@ -89,14 +121,14 @@ class ValueMetadata:
         return self.data.get("unit")
 
     @property
-    def states(self) -> Optional[dict]:
+    def states(self) -> dict:
         """Return (optional) states."""
-        return self.data.get("states")
+        return self.data.get("states", {})
 
     @property
-    def cc_specific(self) -> Optional[Dict[str, Any]]:
+    def cc_specific(self) -> Dict[str, Any]:
         """Return ccSpecific."""
-        return self.data.get("ccSpecific")
+        return self.data.get("ccSpecific", {})
 
 
 class Value:
@@ -106,25 +138,52 @@ class Value:
         """Initialize value."""
         self.node = node
         self.data = data
-        self._value = data.get("value")
+        self._value = data.get("newValue", data.get("value"))
+        if self.metadata.type == "string" and self._value and self._value[0] == "{":
+            try:
+                parsed_val = json.loads(self._value)
+                if (
+                    "type" not in parsed_val
+                    or parsed_val["type"] != "Buffer"
+                    or "data" not in parsed_val
+                ):
+                    raise ValueError("JSON string does not match expected schema")
+                self._value = "".join([chr(x) for x in parsed_val["data"]])
+            except ValueError as err:
+                raise UnparseableValue(
+                    f"Unparseable value {self}: {self.value}"
+                ) from err
 
     def __repr__(self) -> str:
         """Return the representation."""
         return f"{type(self).__name__}(value_id={self.value_id!r})"
 
+    def __hash__(self) -> int:
+        """Return the hash."""
+        return hash((self.node, self.value_id))
+
+    def __eq__(self, other: object) -> bool:
+        """Return whether this instance equals another."""
+        if not isinstance(other, Value):
+            return False
+        return self.node == other.node and self.value_id == other.value_id
+
     @property
     def value_id(self) -> str:
         """Return value ID."""
-        return get_value_id(self.node, self.data)
+        return _get_value_id_from_dict(self.node, self.data)
 
     @property
     def metadata(self) -> ValueMetadata:
         """Return value metadata."""
-        return ValueMetadata(self.data["metadata"])
+        return ValueMetadata(self.data.get("metadata", {"type": "unknown"}))
 
     @property
     def value(self) -> Optional[Any]:
         """Return value."""
+        # Treat unknown values like they are None
+        if self._value == VALUE_UNKNOWN:
+            return None
         return self._value
 
     @property
@@ -174,13 +233,15 @@ class Value:
 
     def receive_event(self, event: Event) -> None:
         """Receive an event."""
-        self.data.update(event.data["args"])
-        self._value = event.data["args"].get("newValue")
+        self.update(event.data["args"])
 
     def update(self, data: ValueDataType) -> None:
         """Update data."""
         self.data.update(data)
-        self._value = data.get("value")
+        if "newValue" in data:
+            self._value = data["newValue"]
+        if "value" in data:
+            self._value = data["value"]
 
 
 class ValueNotification(Value):
@@ -191,3 +252,20 @@ class ValueNotification(Value):
     """
 
     # format is the same as a Value message, subclassed for easier identifying and future use
+
+
+class ConfigurationValue(Value):
+    """Model for a Configuration Value."""
+
+    @property
+    def configuration_value_type(self) -> ConfigurationValueType:
+        """Return configuration value type."""
+        if self.metadata.type == "number":
+            if self.metadata.states:
+                return ConfigurationValueType.ENUMERATED
+            if (
+                self.metadata.max is not None or self.metadata.min is not None
+            ) and not self.metadata.max == self.metadata.min == 0:
+                return ConfigurationValueType.RANGE
+
+        return ConfigurationValueType.UNDEFINED
